@@ -8,9 +8,6 @@ __all__ = [
 from abc import ABC, abstractmethod
 from typing import List, Set, Union
 
-import numpy as np
-import numpy.typing as npt
-
 from ...core import (
     AlgebraicMixin,
     BaseModel,
@@ -18,13 +15,12 @@ from ...core import (
     RateMixin,
     StoichiometricMixin,
 )
+from ...typing import Array, ArrayLike
 
 
 class _AbstractStoichiometricModel(StoichiometricMixin, CompoundMixin, BaseModel, ABC):
     @abstractmethod
-    def _get_rhs(
-        self, t: Union[float, List[float], npt.NDArray[np.float64]], y: List[npt.NDArray[np.float64]]
-    ) -> npt.NDArray[np.float64]:
+    def _get_rhs(self, t: Union[float, ArrayLike], y: List[Array]) -> Array:
         pass
 
 
