@@ -2,6 +2,7 @@ from __future__ import annotations
 
 __all__ = ["LabelModel"]
 
+import copy
 import itertools as it
 import warnings
 from collections import defaultdict
@@ -53,6 +54,26 @@ class LabelModel(Model):
             meta_info=meta_info,
         )
 
+    def __enter__(self) -> LabelModel:
+        """Enter the context manager.
+
+        Returns
+        -------
+            Deepcopy of the model object
+        """
+        self._copy = self.copy()
+        return self.copy()
+
+    def copy(self) -> LabelModel:
+        """Create a deepcopy of the model.
+
+        Returns
+        -------
+        model
+            Deepcopy of the model object
+        """
+        return copy.deepcopy(self)  # type: ignore
+
     @staticmethod
     def _generate_binary_labels(*, base_name: str, num_labels: int) -> List[str]:
         """Create binary label string.
