@@ -6,6 +6,7 @@ __all__ = [
     "Model",
 ]
 
+import copy
 import itertools as it
 import subprocess
 import warnings
@@ -28,7 +29,7 @@ from ...typing import Array, ArrayLike
 from . import _AbstractRateModel
 
 
-class Model(_AbstractRateModel):
+class Model(_AbstractRateModel, BaseModel):
     """The main class for modeling. Provides model construction and inspection tools."""
 
     def __init__(
@@ -49,6 +50,26 @@ class Model(_AbstractRateModel):
         RateMixin.__init__(self, rates=rates, functions=functions)
         self.meta_info["model"].sbo = "SBO:0000062"  # continuous framework
 
+    def __enter__(self) -> Model:
+        """Enter the context manager.
+
+        Returns
+        -------
+            Deepcopy of the model object
+        """
+        self._copy = self.copy()
+        return self.copy()
+
+    def copy(self) -> Model:
+        """Create a deepcopy of the model.
+
+        Returns
+        -------
+        model
+            Deepcopy of the model object
+        """
+        return copy.deepcopy(self)  # type: ignore
+
     def __str__(self) -> str:
         """Give a string representation.
 
